pub struct VectorMemoryStore<E, V> { /* private fields */ }Expand description
A long-term memory that stores conversation turns as vector embeddings and retrieves the most relevant memories for each new query.
Implementations
Sourceimpl<E, V> VectorMemoryStore<E, V>
impl<E, V> VectorMemoryStore<E, V>
Sourcepub fn new(embedder: Arc<E>, store: Arc<V>, top_k: usize) -> Self
pub fn new(embedder: Arc<E>, store: Arc<V>, top_k: usize) -> Self
Create a new VectorMemoryStore.
embedder: converts text to vectorsstore: the underlying vector storetop_k: number of memories to retrieve per query
Sourcepub fn with_memory_key(self, key: impl Into<String>) -> Self
pub fn with_memory_key(self, key: impl Into<String>) -> Self
Override the key used in the returned memory variables map.